#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "device.h"

static bool keep_running = false;

static void handle_term(int signum) 
{
        if (signum != SIGTERM)
                return;
        keep_running = false;
}

int
main(int argc, char* argv[]) 
{
        if (argc != 3) {
                fprintf(stderr, "Use %s DEVICE POWERSAVE.\n", argv[0]);
                return EXIT_FAILURE;
        }

        if (signal(SIGTERM, handle_term) == SIG_ERR) {
                fprintf(stderr, "Cannot set signal handler.\n");
                return EXIT_FAILURE;
        }

        keep_running = true;

        char* name = argv[1];
        bool powersave = !strncmp(argv[2], "on", 2);

        printf("Starting powersave monitor for %s\n", name);
        Device* device = NULL;
        do {
                sleep(1);
                device_free(device);
                bool ps;
                device = device_new(name);
                if (device == NULL) {
                        fprintf(stderr, "Could not get device %s\n", name);
                        continue;
                }
                if (!device_get_powersave(device, &ps)) {
                        fprintf(stderr, "Could not get powersave for %s\n",
                                name);
                        continue;
                }
                if (!ps)
                        continue;
                if (!device_set_powersave(device, powersave)) {
                        fprintf(stderr, "Could not set powersave for %s\n",
                                name);
                        continue;
                }
        } while (keep_running);
        printf("Stopping powersave monitor for %s\n", name);

        return EXIT_SUCCESS;
}
